#
# spec file for package kgpg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define kf6_version 6.0.0
%define qt6_version 6.4.0

%bcond_without released
Name:           kgpg
Version:        24.02.2
Release:        1.1
Summary:        Encryption Tool
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/kgpg
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
Patch0:         kgpg-autostart.diff
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libgpgme-devel
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  cmake(KF6Archive)
BuildRequires:  cmake(KF6CalendarCore)
BuildRequires:  cmake(KF6Codecs)
BuildRequires:  cmake(KF6CoreAddons)
BuildRequires:  cmake(KF6Contacts)
BuildRequires:  cmake(KF6Crash)
BuildRequires:  cmake(KF6DBusAddons)
BuildRequires:  cmake(KF6DocTools)
BuildRequires:  cmake(KF6I18n)
BuildRequires:  cmake(KF6JobWidgets)
BuildRequires:  cmake(KF6KIO)
BuildRequires:  cmake(KF6Notifications)
BuildRequires:  cmake(KF6Service)
BuildRequires:  cmake(KF6StatusNotifierItem)
BuildRequires:  cmake(KF6TextWidgets)
BuildRequires:  cmake(KF6XmlGui)
BuildRequires:  cmake(KF6WidgetsAddons)
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(KPim6AkonadiContactWidgets)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)
Requires:       gpg2

%description
Kgpg is a simple GUI for gpg

%lang_package

%prep
%autosetup -p0

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-man --with-html --all-name

%files
%license LICENSES/*
%doc AUTHORS
%config %{_kf6_configdir}/autostart/org.kde.kgpg.desktop
%doc %lang(en) %{_kf6_htmldir}/en/kgpg/
%dir %{_kf6_sharedir}/kio
%dir %{_kf6_sharedir}/kio/servicemenus
%{_kf6_applicationsdir}/org.kde.kgpg.desktop
%{_kf6_appstreamdir}/org.kde.kgpg.appdata.xml
%{_kf6_bindir}/kgpg
%{_kf6_configkcfgdir}/kgpg.kcfg
%{_kf6_dbusinterfacesdir}/org.kde.kgpg.Key.xml
%{_kf6_debugdir}/kgpg.categories
%{_kf6_iconsdir}/hicolor/*/*/*
%{_kf6_sharedir}/kio/servicemenus/kgpg_encryptfile.desktop
%{_kf6_sharedir}/kio/servicemenus/kgpg_encryptfolder.desktop
%{_kf6_sharedir}/kio/servicemenus/kgpg_viewdecrypted.desktop

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kgpg/

%changelog
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Use KLazyLocalizedString to init static lokalized string (kde#475232)
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Require akonadi-contacts >= 23.07.80
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * remove pointless if
  * Adapt to new akonadi-contacts library names
  * Fix build system for building against qt6/qt5
  * Prepare to qt6 build system
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Adapt to new akonadi include path
  * Kdelibs4ConfigMigrator will be removed in qt6
  * Install Dolphin service files namespaced with kgpg_
  * fix many code quality warnings from CI
  * tests: unify and prolong test timeouts
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * update list of keyservers
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * add missing space between gnupg arguments when generating key in expert mode (kde#447611)
  * always close the input channel of a text decryption (kde#444848)
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Add Free BSD CI
  * Fix entry in kde-ci.yml and syntax of .gitlab-ci.yml
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Disable at the moment as it depends against pim package not only
  * Try to make it compile on CI, it seems that it doesn't find
    akonadi-contacts no idea why at the moment
  * Add CI linux
  * We depend against qt5.15 so we can use directly qt macro
  * Port away from deprecated KFontChooser methods
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Remove obsolete COPYING file
  * Manually adjustments & cleanup for SPDX license statements
  * Convert license headers to SPDX
  * We depend against new qt/kf5 version
  * Reduce it
  * Make compile without deprecated method
  * emit->Q_EMIT
  * Time to increase version
  * Add build support in cmake presets
  * Exclude some asan warning
  * Allow to support cmake presets support
  * Install po/doc file
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Changes since 20.08.3:
  * use the configured config file and directory when generating keys in expert mode (kde#428215)
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Use QIcon over QPixmap and port away from KIconThemes
  * Port KRun to OpenUrlJob
  * Port deprecated method
  * Use KF5_MIN_VERSION
  * Remove unused x-KDE-autostart-after=panel
  * Using no deprecated enum Qt::MiddleButton
  * Port away from deprecated KToolInvocation::startServiceByDesktopName
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * Don't specify an image viewer when opening a key's photo (kde#400324)
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Changes since 20.04.3:
  * remove code to migrate KDE 3.5 keyserver list
  * Use semantically correct icon for Dolphin addon menu items (kde#420457)
  * Port QRegExp to QRegularExpression
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * use the selected export keyserver to upload keys, not the input one (kde#422611)
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * fix -Wzero-as-null-pointer-constant warnings
  * GroupEditProxyModel: fix unintended fallthrough
  * Remove unused include
  * fix indentation
  * Port deprecated enum (scripted)
  * Don't use 0 for flag
  * Fix minor issues found by EBN
- Drop checks for obsolete distribution versions
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Fix compilation with Qt 5.14, QLatin1Literal seems gone
  * Use identical internet-services icon
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * CMake: drop needless endif() argument
  * avoid some needless QString instances
  * CMake: fix version check and whitespace damage
  * Install in new logging directory when we use kf5 5.59.0
  * change links in documentation to https
  * Fix forward declaration
  * update screenshot
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * change some homepage URLs to https
  * remove non-working analyzer URL
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Remove deprecated methods
  * Use <gui> instead of deprecated <kpartgui>
  * Remove deprecated method
  * Remove deprecated method (setMargin->setContentsMargins)
  * use QOverload<>::of instead of static_cast<>
  * use lambda instead of explicit helper function
  * add missing parent
  * update keymanager screenshot in handbook
  * Fix minor Doxygen issues
  * Update screenshots of the handbook.
  * Add override
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Update screenshots of the handbook.
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Add donation url to appdata
  * Add caption to the screenshot
  * avoid needless partitions of QStrings
  * update template for pgp.cs.uu.nl key url
  * fix length 16 placeholders in key urls not having length 16
  * improve code to sort signatures
  * avoid conversions to lowercase, just use case insensitive compare functions
  * Add nullptr
  * Add categories files
  * Autogenerate debug
  * Use KDEFrameworkCompilerSettings + add explicit + fix extra ";" + use
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * add .editorconfig
  * Add .arcconfig
  * Use QTEST_GUILESS_MAIN
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix translated labels text cropping in kgpgfirstassistant.
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * fix handling of photoid.jpeg.size question when adding photo ids
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * fix KEY_CONSIDERED lines always resulting in TS_MSG_SEQUENCE errors
  * Resolve decryption failure when message has no version header
  * Resolve decryption failure when message has no version header
  * avoid needless string copy
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Resolve KGpg crashing when setting trust level to ultimate
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * require Qt 5.5
  * use C++11 "= delete" directly
  * use C++11 override keyword directly
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * ignore empty entries in key groups (kde#387408)
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * appdata: update doc URL, more https
* Sat Dec  2 2017 wbauer@tmo.at
- Drop fix-build-gcc48.patch, no longer necessary and it actually
  hasn't been applied anymore since 17.04
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * show creation date of user ids
  * remove needless assignment
  * do not add duplicate "--command-fd=0" to GnuPG commandline
  * set project version in CMake
  * de-uglify QString construction
  * check file existence before opening it, not afterwards
  * remove write-only local variable
  * use range based for loops if the container is const
  * mark end iterator const
  * use nullptr directly
  * the parent of a KGpgNode cannot change
  * collect secret key information when loading public keys
  * breezeify icon, this gives us larger sizes which is needed for appstream
  * Port away from deprecated qSort.
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * fix message after importing keys (kde#368950)
  * do not show message when password changing ends successfully
  * do not flag sequence errors when using pinentry for changing passwords (kde#383958)
  * make PINENTRY_LAUNCHED a hint that can be triggered on
  * fix output filename constructions for files passed on the commandline (kde#385437)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * breezeify icon, this gives us larger sizes which is needed for appstream
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * don't let signing be confused by KEY_CONSIDERED lines (kde#382903)
  * show trust and owner trust strings as tooltips in key model (kde#369609)
  * use the same text for owner trust values everywhere
  * do not always warn when creating a revocation certificate (kde#372063)
  * use the same code to generate revoke url filenames everywhere
  * fix GnuPG error messages missing if key generation fails
  * introduce Convert::toDateTime() to parse time specifications as returned from GnuPG
  * several code cleanups
  * simplify KgpgTrustLabel creation
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Immediately honor encryption with untrusted keys setting
  * do not show error when KEY_CONSIDERED line is emitted by GnuPG when changing key disable
  * show proper trust value for disabled keys in key list (kde#381493)
  * prevent updates to already deleted dialog (kde#373910)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Compile with gcc <= 4.8
- Remove patches, now upstream:
  * 0002-Revert-Use-new-slot-syntax-for-KStandardAction-conne.patch
  * 0003-Revert-Increase-KF5-requirement.patch
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Mon Feb  6 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
- Drop 0001-fix-crash-when-GnuPG-does-not-output-curve-fields-fo.patch,
  included in this release
* Fri Jan  6 2017 wbauer@tmo.at
- Add 0001-fix-crash-when-GnuPG-does-not-output-curve-fields-fo.patch,
  0002-Revert-Use-new-slot-syntax-for-KStandardAction-conne.patch,
  0003-Revert-Increase-KF5-requirement.patch (as requested by the
  upstream maintainer) to fix the following issues:
  * fix build with older KF5 versions
  * include another crash fix (kde#374509)
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
- Added patches:
  + fix-build-gcc48.patch
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Tue Apr  5 2016 wbauer@tmo.at
- Fix filelist for 13.1, we don't install KF5 ServiceMenus there...
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Wed Jan 20 2016 wbauer@tmo.at
- Fix ServiceMenus symlinks for KF5/Plasma5, they were pointing to
  nowhere (boo#959490)
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Thu Dec 17 2015 tchvatal@suse.com
- Install properly the ServiceMenus on plasma5 bnc#959490
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Fri Mar 14 2014 hrvoje.senjan@gmail.com
- Kgpg can operate without kdepim4-runtime, so make it a Recommends
  instead of requires
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
- patch 4_7_branch.diff removed (no content)
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Mon Jan 30 2012 saschpe@suse.de
- Ran spec-cleaner
- Removed outdated dependencies left from package split
* Thu Jan 19 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan  3 2012 dmueller@suse.de
- update to 4.7.97
* Mon Jan  2 2012 dmueller@suse.de
- update to 4.7.96
* Tue Dec 20 2011 dmueller@suse.de
- update to 4.7.95
* Sat Dec  3 2011 dmueller@suse.de
- update to 4.7.90
* Thu Nov 17 2011 dmueller@suse.de
- update to 4.7.80
* Fri Nov  4 2011 dmueller@suse.de
- update to 4.7.46
* Thu Oct 20 2011 dmueller@suse.de
- update to 4.7.45
* Tue Oct 11 2011 dmueller@suse.de
- update to 4.7.44
* Mon Sep 26 2011 dmueller@suse.de
- update to 4.7.43
* Mon Aug 22 2011 dmueller@suse.de
- update to 4.7.41
* Sat Jul  9 2011 dmueller@suse.de
- update to 4.6.95
* Tue Jun 28 2011 dmueller@suse.de
- update to 4.6.90
* Fri May 20 2011 dmueller@suse.de
- update to 4.6.80
* Fri May 20 2011 dmueller@suse.de
- update to 4.6.79_20110520
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Fri Jan  7 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Wed May 19 2010 llunak@novell.com
- printer-applet requires system-config-printer to run (bnc#551958)
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Fri Jan  8 2010 llunak@novell.com
- kdessh is no longer part of kdeutils
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Fri Nov 20 2009 beineri@opensuse.org
- updated patch to apply with fuzz=0
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: okteta, kgpg, kwallet, kdelirc, ark fixes
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Tue Aug 18 2009 beineri@opensuse.org
- fix irkick menu entry icon
* Sun Aug 16 2009 beineri@opensuse.org
- move superkaramba menu entry to System/Desktop Applet/
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Wed Feb 18 2009 dmueller@suse.de
- update branch diff
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Wed Jan 14 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to KDE 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Mon Oct 20 2008 stbinner@suse.de
- fix build on s390/s390x
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Tue Aug 19 2008 stbinner@suse.de
- branch diff update (many ark bug fixes)
* Thu Jul 31 2008 dmueller@suse.de
- branch diff update
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Fri Jul 18 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Fri Jul  4 2008 dmueller@suse.de
- update to 4.0.85
* Tue Jul  1 2008 stbinner@suse.de
- fix build
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Wed Jun  4 2008 dmueller@suse.de
- Fix build
* Tue Jun  3 2008 wstephenson@suse.de
- Fix handling of numbers in some locales (bnc#396482)
* Tue May 27 2008 stbinner@suse.de
- fix menu entry for sweeper (bnc#394348)
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Fri Apr 25 2008 dmueller@suse.de
- fix filelist
* Mon Apr  7 2008 dmueller@suse.de
- build ark against libzip
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Tue Mar 11 2008 dmueller@suse.de
- 4_0_BRANCH.diff update
  * various bugfixes, translation update
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Sun Feb  3 2008 stbinner@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Wed Oct 31 2007 dmueller@suse.de
- fix free() call
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Thu Oct 18 2007 dmueller@suse.de
- update to 3.94.1
* Thu Oct 11 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720587
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712063
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703919
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700769
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Wed Jul 18 2007 dmueller@suse.de
- remove xmms-devel
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685971
* Wed Jun 27 2007 stbinner@suse.de
- fix build in beta
* Tue Jun 26 2007 dmueller@suse.de
- fix file conflicts
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679151
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Mon Jun  4 2007 stbinner@suse.de
- fix build
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Mon May 28 2007 dmueller@suse.de
- update to 3.90.1.svn668119
* Sat May 12 2007 schwab@suse.de
- Fix dependencies.
* Sat May 12 2007 stbinner@suse.de
- libkdeinit -> libkdeinit4
* Fri May 11 2007 stbinner@suse.de
- initial package in abuild
